====================================
``psyclone.psyir.frontend.fparser2``
====================================

.. automodule:: psyclone.psyir.frontend.fparser2

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.frontend.fparser2


Classes
=======

- :py:class:`Fparser2Reader`:
  Class to encapsulate the functionality for processing the fparser2 AST and


.. autoclass:: Fparser2Reader
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: Fparser2Reader
      :parts: 1
